CREATE SCHEMA IF NOT EXISTS `rtd`;

CREATE SCHEMA IF NOT EXISTS `rtdxls`;

CREATE TABLE IF NOT EXISTS `rtd`.`real_time_formulas` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `TABLE_SCHEMA` VARCHAR(128) NOT NULL,
    `TABLE_NAME` VARCHAR(128) NOT NULL,
    `COLUMN_NAME` VARCHAR(128) NOT NULL,
    `RTD_FORMULA` VARCHAR(255) NULL,
    `IS_DISABLED` TINYINT NULL,
  PRIMARY KEY (`ID`)
);

ALTER TABLE `rtd`.`real_time_formulas`
    ADD UNIQUE INDEX `ix_real_time_formulas_schema_name_column_name`
    USING BTREE (
       `TABLE_SCHEMA`,
       `TABLE_NAME`,
       `COLUMN_NAME`
    );


CREATE TABLE IF NOT EXISTS `rtd`.`real_time_tables` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `TABLE_SCHEMA` VARCHAR(128) NOT NULL,
    `TABLE_NAME` VARCHAR(128) NOT NULL,
    `LOAD_CODE` VARCHAR(2000) NULL,
    `IS_HISTORY` TINYINT NULL,
    `IS_DISABLED` TINYINT NULL,
    `TIME_ZONE` VARCHAR(50) NULL,
    `RTD_INSTANCE_NAME` VARCHAR(50) NULL,
  PRIMARY KEY (`ID`)
);

ALTER TABLE `rtd`.`real_time_tables`
    ADD UNIQUE INDEX `ix_realtimetables_schema_name`
    USING BTREE (
       `TABLE_SCHEMA`,
       `TABLE_NAME`
    );


CREATE TABLE IF NOT EXISTS `rtd`.`fundamentals_day_history_yahoo` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `LAST_TRADE_DATE` DATE NOT NULL,
    `LAST_TRADE_TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `VOLUME` INTEGER NULL,
    `DAYS_RANGE` VARCHAR(50) NULL,
    `PREV_CLOSE` DOUBLE NULL,
    `SHORT_RATIO` DOUBLE NULL,
    `YEAR_HIGH` DOUBLE NULL,
    `YEAR_LOW` DOUBLE NULL,
    `YEAR_RANGE` VARCHAR(50) NULL,
    `CHANGE_FROM_YEAR_HIGH` DOUBLE NULL,
    `CHANGE_FROM_YEAR_LOW` DOUBLE NULL,
    `PERCENT_CHANGE_FROM_YEAR_HIGH` DOUBLE NULL,
    `PERCENT_CHANGE_FROM_YEAR_LOW` DOUBLE NULL,
    `MA50` DOUBLE NULL,
    `MA200` DOUBLE NULL,
    `CHANGE_FROM_MA50` DOUBLE NULL,
    `CHANGE_FROM_MA200` DOUBLE NULL,
    `PERCENT_CHANGE_FROM_MA50` DOUBLE NULL,
    `PERCENT_CHANGE_FROM_MA200` DOUBLE NULL,
    `AVERAGE_DAILY_VOLUME` BIGINT NULL,
    `ONE_YEAR_TARGET_PRICE` DOUBLE NULL,
    `PE` DOUBLE NULL,
    `PEG` DOUBLE NULL,
    `EPS_EST_CURRENT_YEAR` DOUBLE NULL,
    `EPS_EST_NEXT_QUARTER` DOUBLE NULL,
    `EPS_EST_NEXT_YEAR` DOUBLE NULL,
    `EARNINGS_SHARE` DOUBLE NULL,
    `MARKET_CAP` VARCHAR(50) NULL,
    `DIVIDEND_YIELD` DOUBLE NULL,
    `DIVIDEND_SHARE` DOUBLE NULL,
    `EX_DIVIDEND_DATE` VARCHAR(50) NULL,
    `DIVIDEND_PAY_DATE` VARCHAR(50) NULL,
    `BOOK_VALUE` DOUBLE NULL,
    `PRICE_BOOK` DOUBLE NULL,
    `PRICE_SALES` DOUBLE NULL,
    `PRICE_EPS_EST_CURRENT_YEAR` DOUBLE NULL,
    `PRICE_EPS_EST_NEXT_YEAR` DOUBLE NULL,
    `EBITDA` VARCHAR(50) NULL,
    `COMPANY_NAME` VARCHAR(255) NULL,
    `STOCK_EXCHANGE` VARCHAR(50) NULL,
    `COMMISSION` VARCHAR(50) NULL,
    `NOTES` VARCHAR(255) NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `LAST_TRADE_DATE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`fundamentals_yahoo` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `LAST_TRADE_DATE` DATE NOT NULL,
    `LAST_TRADE_TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `VOLUME` INTEGER NULL,
    `DAYS_RANGE` VARCHAR(50) NULL,
    `PREV_CLOSE` DOUBLE NULL,
    `SHORT_RATIO` DOUBLE NULL,
    `YEAR_HIGH` DOUBLE NULL,
    `YEAR_LOW` DOUBLE NULL,
    `YEAR_RANGE` VARCHAR(50) NULL,
    `CHANGE_FROM_YEAR_HIGH` DOUBLE NULL,
    `CHANGE_FROM_YEAR_LOW` DOUBLE NULL,
    `PERCENT_CHANGE_FROM_YEAR_HIGH` DOUBLE NULL,
    `PERCENT_CHANGE_FROM_YEAR_LOW` DOUBLE NULL,
    `MA50` DOUBLE NULL,
    `MA200` DOUBLE NULL,
    `CHANGE_FROM_MA50` DOUBLE NULL,
    `CHANGE_FROM_MA200` DOUBLE NULL,
    `PERCENT_CHANGE_FROM_MA50` DOUBLE NULL,
    `PERCENT_CHANGE_FROM_MA200` DOUBLE NULL,
    `AVERAGE_DAILY_VOLUME` BIGINT NULL,
    `ONE_YEAR_TARGET_PRICE` DOUBLE NULL,
    `PE` DOUBLE NULL,
    `PEG` DOUBLE NULL,
    `EPS_EST_CURRENT_YEAR` DOUBLE NULL,
    `EPS_EST_NEXT_QUARTER` DOUBLE NULL,
    `EPS_EST_NEXT_YEAR` DOUBLE NULL,
    `EARNINGS_SHARE` DOUBLE NULL,
    `MARKET_CAP` VARCHAR(50) NULL,
    `DIVIDEND_YIELD` DOUBLE NULL,
    `DIVIDEND_SHARE` DOUBLE NULL,
    `EX_DIVIDEND_DATE` VARCHAR(50) NULL,
    `DIVIDEND_PAY_DATE` VARCHAR(50) NULL,
    `BOOK_VALUE` DOUBLE NULL,
    `PRICE_BOOK` DOUBLE NULL,
    `PRICE_SALES` DOUBLE NULL,
    `PRICE_EPS_EST_CURRENT_YEAR` DOUBLE NULL,
    `PRICE_EPS_EST_NEXT_YEAR` DOUBLE NULL,
    `EBITDA` VARCHAR(50) NULL,
    `COMPANY_NAME` VARCHAR(255) NULL,
    `STOCK_EXCHANGE` VARCHAR(50) NULL,
    `COMMISSION` VARCHAR(50) NULL,
    `NOTES` VARCHAR(255) NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`option_day_history_tos` (
    `CODE` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` SMALLINT NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` SMALLINT NULL,
    `ASK_SIZE` SMALLINT NULL,
    `BID_ASK_SIZE` VARCHAR(50) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` INTEGER NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `RHO` DOUBLE NULL,
    `EXTRINSIC` DOUBLE NULL,
    `INTRINSIC` DOUBLE NULL,
    `PROBABILITY_ITM` DOUBLE NULL,
    `PROBABILITY_OTM` DOUBLE NULL,
    `PROBABILITY_TOUCH` DOUBLE NULL,
    `COVERED_RETURN` DOUBLE NULL,
    `MAX_COVERED_RETURN` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`, `DATE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`option_day_history_tws` (
    `CODE` VARCHAR(255) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `UNDERLYING_PRICE` DOUBLE NULL,
    `MODEL_PRICE` DOUBLE NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `BID_IMPLIED_VOL` DOUBLE NULL,
    `ASK_IMPLIED_VOL` DOUBLE NULL,
    `LAST_IMPLIED_VOL` DOUBLE NULL,
    `BID_DELTA` DOUBLE NULL,
    `ASK_DELTA` DOUBLE NULL,
    `LAST_DELTA` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `PV_DIVIDEND` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`, `DATE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`option_day_history_yahoo` (
    `CODE` VARCHAR(50) NOT NULL,
    `OPTION_CODE` VARCHAR(50) NOT NULL,
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `OPTION_SYMBOL` VARCHAR(50) NOT NULL,
    `EXP_DATE` DATE NOT NULL,
    `STRIKE` DOUBLE NOT NULL,
    `TYPE` VARCHAR(50) NOT NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `MARK` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `VOLUME` INTEGER NOT NULL,
    `OPEN_INT` INTEGER NOT NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`, `DATE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`option_list_tos` (
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`option_list_yahoo` (
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`options_tos` (
    `CODE` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` SMALLINT NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` SMALLINT NULL,
    `ASK_SIZE` SMALLINT NULL,
    `BID_ASK_SIZE` VARCHAR(50) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` INTEGER NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `RHO` DOUBLE NULL,
    `EXTRINSIC` DOUBLE NULL,
    `INTRINSIC` DOUBLE NULL,
    `PROBABILITY_ITM` DOUBLE NULL,
    `PROBABILITY_OTM` DOUBLE NULL,
    `PROBABILITY_TOUCH` DOUBLE NULL,
    `COVERED_RETURN` DOUBLE NULL,
    `MAX_COVERED_RETURN` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`options_tws` (
    `CODE` VARCHAR(255) NOT NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `UNDERLYING_PRICE` DOUBLE NULL,
    `MODEL_PRICE` DOUBLE NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `BID_IMPLIED_VOL` DOUBLE NULL,
    `ASK_IMPLIED_VOL` DOUBLE NULL,
    `LAST_IMPLIED_VOL` DOUBLE NULL,
    `BID_DELTA` DOUBLE NULL,
    `ASK_DELTA` DOUBLE NULL,
    `LAST_DELTA` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `PV_DIVIDEND` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`options_yahoo` (
    `CODE` VARCHAR(50) NOT NULL,
    `OPTION_CODE` VARCHAR(50) NOT NULL,
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `OPTION_SYMBOL` VARCHAR(50) NOT NULL,
    `EXP_DATE` DATE NOT NULL,
    `STRIKE` DOUBLE NOT NULL,
    `TYPE` VARCHAR(50) NOT NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `MARK` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `VOLUME` INTEGER NOT NULL,
    `OPEN_INT` INTEGER NOT NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`option_tick_history_tos` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `CODE` VARCHAR(50) NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` SMALLINT NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` SMALLINT NULL,
    `ASK_SIZE` SMALLINT NULL,
    `BID_ASK_SIZE` VARCHAR(50) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` INTEGER NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `RHO` DOUBLE NULL,
    `EXTRINSIC` DOUBLE NULL,
    `INTRINSIC` DOUBLE NULL,
    `PROBABILITY_ITM` DOUBLE NULL,
    `PROBABILITY_OTM` DOUBLE NULL,
    `PROBABILITY_TOUCH` DOUBLE NULL,
    `COVERED_RETURN` DOUBLE NULL,
    `MAX_COVERED_RETURN` DOUBLE NULL,
  PRIMARY KEY (`ID`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`option_tick_history_tws` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `CODE` VARCHAR(255) NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `UNDERLYING_PRICE` DOUBLE NULL,
    `MODEL_PRICE` DOUBLE NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `BID_IMPLIED_VOL` DOUBLE NULL,
    `ASK_IMPLIED_VOL` DOUBLE NULL,
    `LAST_IMPLIED_VOL` DOUBLE NULL,
    `BID_DELTA` DOUBLE NULL,
    `ASK_DELTA` DOUBLE NULL,
    `LAST_DELTA` DOUBLE NULL,
    `DELTA` DOUBLE NULL,
    `GAMMA` DOUBLE NULL,
    `THETA` DOUBLE NULL,
    `VEGA` DOUBLE NULL,
    `PV_DIVIDEND` DOUBLE NULL,
  PRIMARY KEY (`ID`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`option_tick_history_yahoo` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `CODE` VARCHAR(50) NOT NULL,
    `OPTION_CODE` VARCHAR(50) NOT NULL,
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `OPTION_SYMBOL` VARCHAR(50) NOT NULL,
    `EXP_DATE` DATE NOT NULL,
    `STRIKE` DOUBLE NOT NULL,
    `TYPE` VARCHAR(50) NOT NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `MARK` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `VOLUME` INTEGER NOT NULL,
    `OPEN_INT` INTEGER NOT NULL,
  PRIMARY KEY (`ID`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_day_history_es` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `TRADE_PRICE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `DATE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_day_history_tos` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `BID_ASK_SIZE` VARCHAR(255) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `STRENGTH_METER` VARCHAR(255) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `VOL_INDEX` DOUBLE NULL,
    `FRONT_VOL` DOUBLE NULL,
    `BACK_VOL` DOUBLE NULL,
    `WEIGHTED_BACK_VOL` DOUBLE NULL,
    `VOL_DIFF` DOUBLE NULL,
    `PUT_CALL_RATIO` DOUBLE NULL,
    `CALL_VOLUME_INDEX` DOUBLE NULL,
    `PUT_VOLUME_INDEX` DOUBLE NULL,
    `OPTION_VOLUME_INDEX` DOUBLE NULL,
    `FRONT_EXPECTED_MOVE` DOUBLE NULL,
    `BACK_EXPECTED_MOVE` DOUBLE NULL,
    `EXPECTED_MOVE_DIFF` DOUBLE NULL,
    `BETA` DOUBLE NULL,
    `HIGH52` DOUBLE NULL,
    `LOW52` DOUBLE NULL,
    `PE` DOUBLE NULL,
    `EPS` DOUBLE NULL,
    `MARKET_CAP` VARCHAR(255) NULL,
    `SHARES` BIGINT NULL,
    `DIVIDEND_YIELD` DOUBLE NULL,
    `DIVIDEND_SHARE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `DATE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_day_history_tws` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `DATE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_day_history_vfx` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `DATE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_day_history_yahoo` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `LAST_TRADE_DATE` DATE NOT NULL,
    `LAST_TRADE_TIME` TIME NOT NULL,
    `LAST` DOUBLE NOT NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `OPEN` DOUBLE NOT NULL,
    `HIGH` DOUBLE NOT NULL,
    `LOW` DOUBLE NOT NULL,
    `VOLUME` BIGINT NOT NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `LAST_TRADE_DATE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_list_es` (
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_list_stocks` (
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_list_tos` (
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_list_tws` (
    `TICK_ID` INTEGER NOT NULL AUTO_INCREMENT,
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`TICK_ID`)
);

ALTER TABLE `rtd`.`quote_list_tws`
    ADD UNIQUE INDEX `ix_quote_list_tws_code`
    USING BTREE (
        `CODE`
    );


CREATE TABLE IF NOT EXISTS `rtd`.`quote_list_vfx` (
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_list_yahoo` (
    `CODE` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`CODE`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quotes_es` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `TRADE_PRICE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quotes_tos` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NOT NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `BID_ASK_SIZE` VARCHAR(255) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `STRENGTH_METER` VARCHAR(255) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `VOL_INDEX` DOUBLE NULL,
    `FRONT_VOL` DOUBLE NULL,
    `BACK_VOL` DOUBLE NULL,
    `WEIGHTED_BACK_VOL` DOUBLE NULL,
    `VOL_DIFF` DOUBLE NULL,
    `PUT_CALL_RATIO` DOUBLE NULL,
    `CALL_VOLUME_INDEX` DOUBLE NULL,
    `PUT_VOLUME_INDEX` DOUBLE NULL,
    `OPTION_VOLUME_INDEX` DOUBLE NULL,
    `FRONT_EXPECTED_MOVE` DOUBLE NULL,
    `BACK_EXPECTED_MOVE` DOUBLE NULL,
    `EXPECTED_MOVE_DIFF` DOUBLE NULL,
    `BETA` DOUBLE NULL,
    `HIGH52` DOUBLE NULL,
    `LOW52` DOUBLE NULL,
    `PE` DOUBLE NULL,
    `EPS` DOUBLE NULL,
    `MARKET_CAP` VARCHAR(255) NULL,
    `SHARES` BIGINT NULL,
    `DIVIDEND_YIELD` DOUBLE NULL,
    `DIVIDEND_SHARE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quotes_tws` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quotes_vfx` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quotes_yahoo` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `LAST_TRADE_DATETIME` DATETIME NOT NULL,
    `LAST_TRADE_DATE` DATE NOT NULL,
    `LAST_TRADE_TIME` TIME NOT NULL,
    `LAST` DOUBLE NOT NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `OPEN` DOUBLE NOT NULL,
    `HIGH` DOUBLE NOT NULL,
    `LOW` DOUBLE NOT NULL,
    `VOLUME` BIGINT NOT NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_tick_history_es` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `TRADE_PRICE` DOUBLE NULL,
  PRIMARY KEY (`ID`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_tick_history_tos` (
    `ID` BIGINT NOT NULL AUTO_INCREMENT,
    `SYMBOL` VARCHAR(50) NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `DESCRIPTION` VARCHAR(255) NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `LAST_X` CHAR(1) NULL,
    `MARK` DOUBLE NULL,
    `MARK_CHANGE` DOUBLE NULL,
    `MARK_PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `BID_ASK_SIZE` VARCHAR(255) NULL,
    `BID_X` CHAR(1) NULL,
    `ASK_X` CHAR(1) NULL,
    `STRENGTH_METER` VARCHAR(255) NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `IMPLIED_VOL` DOUBLE NULL,
    `VOL_INDEX` DOUBLE NULL,
    `FRONT_VOL` DOUBLE NULL,
    `BACK_VOL` DOUBLE NULL,
    `WEIGHTED_BACK_VOL` DOUBLE NULL,
    `VOL_DIFF` DOUBLE NULL,
    `PUT_CALL_RATIO` DOUBLE NULL,
    `CALL_VOLUME_INDEX` DOUBLE NULL,
    `PUT_VOLUME_INDEX` DOUBLE NULL,
    `OPTION_VOLUME_INDEX` DOUBLE NULL,
    `FRONT_EXPECTED_MOVE` DOUBLE NULL,
    `BACK_EXPECTED_MOVE` DOUBLE NULL,
    `EXPECTED_MOVE_DIFF` DOUBLE NULL,
    `BETA` DOUBLE NULL,
    `HIGH52` DOUBLE NULL,
    `LOW52` DOUBLE NULL,
    `PE` DOUBLE NULL,
    `EPS` DOUBLE NULL,
    `MARKET_CAP` VARCHAR(255) NULL,
    `SHARES` BIGINT NULL,
    `DIVIDEND_YIELD` DOUBLE NULL,
    `DIVIDEND_SHARE` DOUBLE NULL,
  PRIMARY KEY (`ID`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_tick_history_tws` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `SYMBOL` VARCHAR(50) NULL,
    `DATETIME` DATETIME NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `LAST` DOUBLE NULL,
    `LAST_SIZE` INTEGER NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
  PRIMARY KEY (`ID`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_tick_history_vfx` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `SYMBOL` VARCHAR(50) NULL,
    `DATE` DATE NULL,
    `TIME` TIME NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
  PRIMARY KEY (`ID`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_tick_history_yahoo` (
    `ID` INTEGER NOT NULL AUTO_INCREMENT,
    `SYMBOL` VARCHAR(50) NOT NULL,
    `LAST_TRADE_DATETIME` DATETIME NOT NULL,
    `LAST_TRADE_DATE` DATE NOT NULL,
    `LAST_TRADE_TIME` TIME NOT NULL,
    `LAST` DOUBLE NOT NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `OPEN` DOUBLE NOT NULL,
    `HIGH` DOUBLE NOT NULL,
    `LOW` DOUBLE NOT NULL,
    `VOLUME` BIGINT NOT NULL,
  PRIMARY KEY (`ID`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_time_history_es` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `LAST` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `BID_SIZE` INTEGER NULL,
    `ASK_SIZE` INTEGER NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `VOLUME` BIGINT NULL,
    `OPEN_INT` INTEGER NULL,
    `TRADE_PRICE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY
(
    `SYMBOL`,
    `DATE`,
    `TIME`
)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_time_history_vfx` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `DATE` DATE NOT NULL,
    `TIME` TIME NOT NULL,
    `BID` DOUBLE NULL,
    `ASK` DOUBLE NULL,
    `OPEN` DOUBLE NULL,
    `HIGH` DOUBLE NULL,
    `LOW` DOUBLE NULL,
    `CLOSE` DOUBLE NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY
(
    `SYMBOL`,
    `DATE`,
    `TIME`
)
);


CREATE TABLE IF NOT EXISTS `rtd`.`quote_time_history_yahoo` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `LAST_TRADE_DATETIME` DATETIME NOT NULL,
    `LAST_TRADE_DATE` DATE NOT NULL,
    `LAST_TRADE_TIME` TIME NOT NULL,
    `LAST` DOUBLE NOT NULL,
    `CHANGE` DOUBLE NULL,
    `PERCENT_CHANGE` DOUBLE NULL,
    `OPEN` DOUBLE NOT NULL,
    `HIGH` DOUBLE NOT NULL,
    `LOW` DOUBLE NOT NULL,
    `VOLUME` BIGINT NOT NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`, `LAST_TRADE_DATETIME`)
);


CREATE TABLE IF NOT EXISTS `rtd`.`stocks_yahoo` (
    `SYMBOL` VARCHAR(50) NOT NULL,
    `COMPANY_NAME` VARCHAR(255) NULL,
    `SECTOR` VARCHAR(255) NULL,
    `INDUSTRY` VARCHAR(255) NULL,
    `FULLTIME_EMPLOYEES` INTEGER NULL,
    `TRADE_START` DATE NULL,
    `TRADE_END` DATE NULL,
    `LAST_UPDATE_TIMESTAMP` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`SYMBOL`)
);


insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) values ('rtd', 'option_tick_history_tos', 'ID');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) values ('rtd', 'option_tick_history_tos', 'CODE');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'DATETIME', '=DateTime()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'DATE', '=Date()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'TIME', '=Time()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'LAST', '=RTD("tos.rtd",,"LAST",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'LAST_X', '=RTD("tos.rtd",,"LX",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'MARK', '=RTD("tos.rtd",,"MARK",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'BID', '=RTD("tos.rtd",,"BID",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'ASK', '=RTD("tos.rtd",,"ASK",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'BID_X', '=RTD("tos.rtd",,"BX",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'ASK_X', '=RTD("tos.rtd",,"AX",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'OPEN', '=RTD("tos.rtd",,"OPEN",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'HIGH', '=RTD("tos.rtd",,"HIGH",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'LOW', '=RTD("tos.rtd",,"LOW",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'DELTA', '=RTD("tos.rtd",,"DELTA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'GAMMA', '=RTD("tos.rtd",,"GAMMA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'THETA', '=RTD("tos.rtd",,"THETA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'VEGA', '=RTD("tos.rtd",,"VEGA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'RHO', '=RTD("tos.rtd",,"RHO",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'EXTRINSIC', '=RTD("tos.rtd",,"EXTRINSIC",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'INTRINSIC', '=RTD("tos.rtd",,"INTRINSIC",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'PROBABILITY_ITM', '=RTD("tos.rtd",,"PROB_OF_EXPIRING",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'PROBABILITY_OTM', '=RTD("tos.rtd",,"PROB_OTM",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'PROBABILITY_TOUCH', '=RTD("tos.rtd",,"PROB_OF_TOUCHING",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'COVERED_RETURN', '=RTD("tos.rtd",,"COVERED_RETURN",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_tick_history_tos', 'MAX_COVERED_RETURN', '=RTD("tos.rtd",,"MAX_COVERED_RETURN",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) values ('rtd', 'option_day_history_tos', 'CODE');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'DATE', '=Date()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'TIME', '=Time()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'LAST', '=RTD("tos.rtd",,"LAST",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'LAST_X', '=RTD("tos.rtd",,"LX",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'MARK', '=RTD("tos.rtd",,"MARK",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'BID', '=RTD("tos.rtd",,"BID",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'ASK', '=RTD("tos.rtd",,"ASK",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'BID_X', '=RTD("tos.rtd",,"BX",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'ASK_X', '=RTD("tos.rtd",,"AX",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'OPEN', '=RTD("tos.rtd",,"OPEN",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'HIGH', '=RTD("tos.rtd",,"HIGH",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'LOW', '=RTD("tos.rtd",,"LOW",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'DELTA', '=RTD("tos.rtd",,"DELTA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'GAMMA', '=RTD("tos.rtd",,"GAMMA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'THETA', '=RTD("tos.rtd",,"THETA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'VEGA', '=RTD("tos.rtd",,"VEGA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'RHO', '=RTD("tos.rtd",,"RHO",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'EXTRINSIC', '=RTD("tos.rtd",,"EXTRINSIC",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'INTRINSIC', '=RTD("tos.rtd",,"INTRINSIC",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'PROBABILITY_ITM', '=RTD("tos.rtd",,"PROB_OF_EXPIRING",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'PROBABILITY_OTM', '=RTD("tos.rtd",,"PROB_OTM",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'PROBABILITY_TOUCH', '=RTD("tos.rtd",,"PROB_OF_TOUCHING",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'COVERED_RETURN', '=RTD("tos.rtd",,"COVERED_RETURN",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'option_day_history_tos', 'MAX_COVERED_RETURN', '=RTD("tos.rtd",,"MAX_COVERED_RETURN",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) values ('rtd', 'options_tos', 'CODE');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'DATETIME', '=DateTime()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'DATE', '=Date()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'TIME', '=Time()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'LAST', '=RTD("tos.rtd",,"LAST",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'LAST_X', '=RTD("tos.rtd",,"LX",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'MARK', '=RTD("tos.rtd",,"MARK",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'BID', '=RTD("tos.rtd",,"BID",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'ASK', '=RTD("tos.rtd",,"ASK",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'BID_X', '=RTD("tos.rtd",,"BX",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'ASK_X', '=RTD("tos.rtd",,"AX",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'OPEN', '=RTD("tos.rtd",,"OPEN",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'HIGH', '=RTD("tos.rtd",,"HIGH",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'LOW', '=RTD("tos.rtd",,"LOW",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'DELTA', '=RTD("tos.rtd",,"DELTA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'GAMMA', '=RTD("tos.rtd",,"GAMMA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'THETA', '=RTD("tos.rtd",,"THETA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'VEGA', '=RTD("tos.rtd",,"VEGA",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'RHO', '=RTD("tos.rtd",,"RHO",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'EXTRINSIC', '=RTD("tos.rtd",,"EXTRINSIC",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'INTRINSIC', '=RTD("tos.rtd",,"INTRINSIC",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'PROBABILITY_ITM', '=RTD("tos.rtd",,"PROB_OF_EXPIRING",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'PROBABILITY_OTM', '=RTD("tos.rtd",,"PROB_OTM",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'PROBABILITY_TOUCH', '=RTD("tos.rtd",,"PROB_OF_TOUCHING",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'COVERED_RETURN', '=RTD("tos.rtd",,"COVERED_RETURN",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'options_tos', 'MAX_COVERED_RETURN', '=RTD("tos.rtd",,"MAX_COVERED_RETURN",[CODE])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) values ('rtd', 'quote_tick_history_tos', 'ID');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) values ('rtd', 'quote_tick_history_tos', 'SYMBOL');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'DATETIME', '=DateTime()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'DATE', '=Date()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'TIME', '=Time()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'LAST', '=RTD("tos.rtd",,"LAST",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'LAST_X', '=RTD("tos.rtd",,"LX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'MARK', '=RTD("tos.rtd",,"MARK",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'BID', '=RTD("tos.rtd",,"BID",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'ASK', '=RTD("tos.rtd",,"ASK",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'BID_X', '=RTD("tos.rtd",,"BX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'ASK_X', '=RTD("tos.rtd",,"AX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'STRENGTH_METER', '=RTD("tos.rtd",,"STRENGTH_METER",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'OPEN', '=RTD("tos.rtd",,"OPEN",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'HIGH', '=RTD("tos.rtd",,"HIGH",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'LOW', '=RTD("tos.rtd",,"LOW",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'VOL_INDEX', '=RTD("tos.rtd",,"VOL_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'FRONT_VOL', '=RTD("tos.rtd",,"FRONT_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'BACK_VOL', '=RTD("tos.rtd",,"BACK_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'WEIGHTED_BACK_VOL', '=RTD("tos.rtd",,"WEIGHTED_BACK_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'VOL_DIFF', '=RTD("tos.rtd",,"VOL_DIFF",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'PUT_CALL_RATIO', '=RTD("tos.rtd",,"PUT_CALL_RATIO",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'CALL_VOLUME_INDEX', '=RTD("tos.rtd",,"CALL_VOLUME_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'PUT_VOLUME_INDEX', '=RTD("tos.rtd",,"PUT_VOLUME_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'OPTION_VOLUME_INDEX', '=RTD("tos.rtd",,"OPTION_VOLUME_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'FRONT_EXPECTED_MOVE', '=RTD("tos.rtd",,"FRONT_EX_MOVE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'BACK_EXPECTED_MOVE', '=RTD("tos.rtd",,"BACK_EX_MOVE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'EXPECTED_MOVE_DIFF', '=RTD("tos.rtd",,"EX_MOVE_DIFF",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'BETA', '=RTD("tos.rtd",,"BETA",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'HIGH52', '=RTD("tos.rtd",,"52HIGH",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'LOW52', '=RTD("tos.rtd",,"52LOW",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'PE', '=RTD("tos.rtd",,"PE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'EPS', '=RTD("tos.rtd",,"EPS",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'MARKET_CAP', '=RTD("tos.rtd",,"MARKET_CAP",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'SHARES', '=RTD("tos.rtd",,"SHARES",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'DIVIDEND_YIELD', '=RTD("tos.rtd",,"YIELD",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_tick_history_tos', 'DIVIDEND_SHARE', '=RTD("tos.rtd",,"DIV",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) values ('rtd', 'quote_day_history_tos', 'SYMBOL');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'DATE', '=Date()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'TIME', '=Time()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'LAST', '=RTD("tos.rtd",,"LAST",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'LAST_X', '=RTD("tos.rtd",,"LX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'MARK', '=RTD("tos.rtd",,"MARK",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'BID', '=RTD("tos.rtd",,"BID",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'ASK', '=RTD("tos.rtd",,"ASK",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'BID_X', '=RTD("tos.rtd",,"BX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'ASK_X', '=RTD("tos.rtd",,"AX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'STRENGTH_METER', '=RTD("tos.rtd",,"STRENGTH_METER",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'OPEN', '=RTD("tos.rtd",,"OPEN",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'HIGH', '=RTD("tos.rtd",,"HIGH",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'LOW', '=RTD("tos.rtd",,"LOW",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'VOL_INDEX', '=RTD("tos.rtd",,"VOL_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'FRONT_VOL', '=RTD("tos.rtd",,"FRONT_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'BACK_VOL', '=RTD("tos.rtd",,"BACK_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'WEIGHTED_BACK_VOL', '=RTD("tos.rtd",,"WEIGHTED_BACK_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'VOL_DIFF', '=RTD("tos.rtd",,"VOL_DIFF",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'PUT_CALL_RATIO', '=RTD("tos.rtd",,"PUT_CALL_RATIO",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'CALL_VOLUME_INDEX', '=RTD("tos.rtd",,"CALL_VOLUME_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'PUT_VOLUME_INDEX', '=RTD("tos.rtd",,"PUT_VOLUME_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'OPTION_VOLUME_INDEX', '=RTD("tos.rtd",,"OPTION_VOLUME_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'FRONT_EXPECTED_MOVE', '=RTD("tos.rtd",,"FRONT_EX_MOVE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'BACK_EXPECTED_MOVE', '=RTD("tos.rtd",,"BACK_EX_MOVE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'EXPECTED_MOVE_DIFF', '=RTD("tos.rtd",,"EX_MOVE_DIFF",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'BETA', '=RTD("tos.rtd",,"BETA",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'HIGH52', '=RTD("tos.rtd",,"52HIGH",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'LOW52', '=RTD("tos.rtd",,"52LOW",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'PE', '=RTD("tos.rtd",,"PE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'EPS', '=RTD("tos.rtd",,"EPS",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'MARKET_CAP', '=RTD("tos.rtd",,"MARKET_CAP",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'SHARES', '=RTD("tos.rtd",,"SHARES",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'DIVIDEND_YIELD', '=RTD("tos.rtd",,"YIELD",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quote_day_history_tos', 'DIVIDEND_SHARE', '=RTD("tos.rtd",,"DIV",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`) values ('rtd', 'quotes_tos', 'SYMBOL');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'DATETIME', '=DateTime()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'DATE', '=Date()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'TIME', '=Time()');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'DESCRIPTION', '=RTD("tos.rtd",,"DESCRIPTION",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'LAST', '=RTD("tos.rtd",,"LAST",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'CHANGE', '=RTD("tos.rtd",,"NET_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'PERCENT_CHANGE', '=RTD("tos.rtd",,"PERCENT_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'LAST_SIZE', '=RTD("tos.rtd",,"LAST_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'LAST_X', '=RTD("tos.rtd",,"LX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'MARK', '=RTD("tos.rtd",,"MARK",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'MARK_CHANGE', '=RTD("tos.rtd",,"MARK_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'MARK_PERCENT_CHANGE', '=RTD("tos.rtd",,"MARK_PERCENT_CHANGE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'BID', '=RTD("tos.rtd",,"BID",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'ASK', '=RTD("tos.rtd",,"ASK",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'BID_SIZE', '=RTD("tos.rtd",,"BID_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'ASK_SIZE', '=RTD("tos.rtd",,"ASK_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'BID_ASK_SIZE', '=RTD("tos.rtd",,"BA_SIZE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'BID_X', '=RTD("tos.rtd",,"BX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'ASK_X', '=RTD("tos.rtd",,"AX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'STRENGTH_METER', '=RTD("tos.rtd",,"STRENGTH_METER",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'OPEN', '=RTD("tos.rtd",,"OPEN",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'HIGH', '=RTD("tos.rtd",,"HIGH",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'LOW', '=RTD("tos.rtd",,"LOW",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'CLOSE', '=RTD("tos.rtd",,"CLOSE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'VOLUME', '=RTD("tos.rtd",,"VOLUME",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'OPEN_INT', '=RTD("tos.rtd",,"OPEN_INT",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'IMPLIED_VOL', '=RTD("tos.rtd",,"IMPL_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'VOL_INDEX', '=RTD("tos.rtd",,"VOL_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'FRONT_VOL', '=RTD("tos.rtd",,"FRONT_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'BACK_VOL', '=RTD("tos.rtd",,"BACK_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'WEIGHTED_BACK_VOL', '=RTD("tos.rtd",,"WEIGHTED_BACK_VOL",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'VOL_DIFF', '=RTD("tos.rtd",,"VOL_DIFF",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'PUT_CALL_RATIO', '=RTD("tos.rtd",,"PUT_CALL_RATIO",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'CALL_VOLUME_INDEX', '=RTD("tos.rtd",,"CALL_VOLUME_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'PUT_VOLUME_INDEX', '=RTD("tos.rtd",,"PUT_VOLUME_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'OPTION_VOLUME_INDEX', '=RTD("tos.rtd",,"OPTION_VOLUME_INDEX",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'FRONT_EXPECTED_MOVE', '=RTD("tos.rtd",,"FRONT_EX_MOVE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'BACK_EXPECTED_MOVE', '=RTD("tos.rtd",,"BACK_EX_MOVE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'EXPECTED_MOVE_DIFF', '=RTD("tos.rtd",,"EX_MOVE_DIFF",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'BETA', '=RTD("tos.rtd",,"BETA",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'HIGH52', '=RTD("tos.rtd",,"52HIGH",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'LOW52', '=RTD("tos.rtd",,"52LOW",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'PE', '=RTD("tos.rtd",,"PE",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'EPS', '=RTD("tos.rtd",,"EPS",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'MARKET_CAP', '=RTD("tos.rtd",,"MARKET_CAP",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'SHARES', '=RTD("tos.rtd",,"SHARES",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'DIVIDEND_YIELD', '=RTD("tos.rtd",,"YIELD",[SYMBOL])');
insert into `rtd`.`real_time_formulas` (`TABLE_SCHEMA`, `TABLE_NAME`, `COLUMN_NAME`, `RTD_FORMULA`) values ('rtd', 'quotes_tos', 'DIVIDEND_SHARE', '=RTD("tos.rtd",,"DIV",[SYMBOL])');

INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'REQ', N'=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'DATETIME', N'=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'TIME', N'=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'LAST', N'=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'LAST_SIZE', N'=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'BID', N'=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'ASK', N'=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'BID_SIZE', N'=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'ASK_SIZE', N'=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'HIGH', N'=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'LOW', N'=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'CLOSE', N'=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'VOLUME', N'=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'UNDERLYING_PRICE', N'=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'MODEL_PRICE', N'=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'IMPLIED_VOL', N'=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'BID_IMPLIED_VOL', N'=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'ASK_IMPLIED_VOL', N'=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'LAST_IMPLIED_VOL', N'=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'BID_DELTA', N'=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'ASK_DELTA', N'=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'LAST_DELTA', N'=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'DELTA', N'=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'GAMMA', N'=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'THETA', N'=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'VEGA', N'=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_tws', N'PV_DIVIDEND', N'=S|tik!id[TICK_ID]?pvDividend', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'REQ', N'=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'TIME', N'=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'LAST', N'=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'LAST_SIZE', N'=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'BID', N'=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'ASK', N'=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'BID_SIZE', N'=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'ASK_SIZE', N'=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'HIGH', N'=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'LOW', N'=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'CLOSE', N'=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'VOLUME', N'=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'UNDERLYING_PRICE', N'=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'MODEL_PRICE', N'=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'IMPLIED_VOL', N'=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'BID_IMPLIED_VOL', N'=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'ASK_IMPLIED_VOL', N'=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'LAST_IMPLIED_VOL', N'=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'BID_DELTA', N'=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'ASK_DELTA', N'=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'LAST_DELTA', N'=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'DELTA', N'=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'GAMMA', N'=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'THETA', N'=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'VEGA', N'=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_tws', N'PV_DIVIDEND', N'=S|tik!id[TICK_ID]?pvDividend', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'REQ', N'=S|tik!''id[TICK_ID]?req?[CODE]''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'DATETIME', N'=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'TIME', N'=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'LAST', N'=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'LAST_SIZE', N'=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'BID', N'=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'ASK', N'=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'BID_SIZE', N'=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'ASK_SIZE', N'=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'HIGH', N'=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'LOW', N'=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'CLOSE', N'=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'VOLUME', N'=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'UNDERLYING_PRICE', N'=S|tik!id[TICK_ID]?modelUndPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'MODEL_PRICE', N'=S|tik!id[TICK_ID]?modelPrice', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'IMPLIED_VOL', N'=S|tik!id[TICK_ID]?modelVolatility', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'BID_IMPLIED_VOL', N'=S|tik!id[TICK_ID]?bidImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'ASK_IMPLIED_VOL', N'=S|tik!id[TICK_ID]?askImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'LAST_IMPLIED_VOL', N'=S|tik!id[TICK_ID]?lastImpliedVol', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'BID_DELTA', N'=S|tik!id[TICK_ID]?bidDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'ASK_DELTA', N'=S|tik!id[TICK_ID]?askDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'LAST_DELTA', N'=S|tik!id[TICK_ID]?lastDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'DELTA', N'=S|tik!id[TICK_ID]?modelDelta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'GAMMA', N'=S|tik!id[TICK_ID]?modelGamma', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'THETA', N'=S|tik!id[TICK_ID]?modelTheta', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'VEGA', N'=S|tik!id[TICK_ID]?modelVega', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_tws', N'PV_DIVIDEND', N'=S|tik!id[TICK_ID]?pvDividend', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'SYMBOL', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'REQ', N'=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'DATETIME', N'=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'TIME', N'=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'LAST', N'=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'LAST_SIZE', N'=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'BID', N'=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'ASK', N'=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'BID_SIZE', N'=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'ASK_SIZE', N'=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'HIGH', N'=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'LOW', N'=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'CLOSE', N'=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_tws', N'VOLUME', N'=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'SYMBOL', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'REQ', N'=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'TIME', N'=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'LAST', N'=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'LAST_SIZE', N'=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'BID', N'=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'ASK', N'=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'BID_SIZE', N'=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'ASK_SIZE', N'=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'HIGH', N'=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'LOW', N'=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'CLOSE', N'=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_tws', N'VOLUME', N'=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'TICK_ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'SYMBOL', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'REQ', N'=S|tik!''id[TICK_ID]?req?[SYMBOL]_STK_SMART_USD_~''', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'DATETIME', N'=DateTime()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'TIME', N'=Time()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'LAST', N'=S|tik!id[TICK_ID]?last', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'LAST_SIZE', N'=S|tik!id[TICK_ID]?lastSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'BID', N'=S|tik!id[TICK_ID]?bid', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'ASK', N'=S|tik!id[TICK_ID]?ask', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'BID_SIZE', N'=S|tik!id[TICK_ID]?bidSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'ASK_SIZE', N'=S|tik!id[TICK_ID]?askSize', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'HIGH', N'=S|tik!id[TICK_ID]?high', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'LOW', N'=S|tik!id[TICK_ID]?low', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'CLOSE', N'=S|tik!id[TICK_ID]?close', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_tws', N'VOLUME', N'=S|tik!id[TICK_ID]?volume', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'SYMBOL', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'LAST_TRADE_DATE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'LAST_TRADE_TIME', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'LAST', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PERCENT_CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'OPEN', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'HIGH', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'LOW', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'DAYS_RANGE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DaysRange")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PREV_CLOSE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PreviousClose")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'SHORT_RATIO', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ShortRatio")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'YEAR_HIGH', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearHigh")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'YEAR_LOW', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearLow")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'YEAR_RANGE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearRange")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'CHANGE_FROM_YEAR_HIGH', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromYearHigh")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'CHANGE_FROM_YEAR_LOW', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromYearLow")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PERCENT_CHANGE_FROM_YEAR_HIGH', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromYearHigh")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PERCENT_CHANGE_FROM_YEAR_LOW', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromYearLow")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'MA50', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"FiftydayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'MA200', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"TwoHundredDayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'CHANGE_FROM_MA50', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromFiftyDayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'CHANGE_FROM_MA200', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromTwoHundredDayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PERCENT_CHANGE_FROM_MA50', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromFiftyDayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PERCENT_CHANGE_FROM_MA200', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromTwoHundredDayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'AVERAGE_DAILY_VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"AverageDailyVolume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'ONE_YEAR_TARGET_PRICE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"OneYrTargetPrice")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PERatio")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PEG', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PEGRatio")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'EPS_EST_CURRENT_YEAR', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateCurrentYear")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'EPS_EST_NEXT_QUARTER', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateNextQuarter")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'EPS_EST_NEXT_YEAR', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateNextYear")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'EARNINGS_SHARE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EarningsShare")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'MARKET_CAP', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"MarketCapitalization")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'DIVIDEND_YIELD', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendYield")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'DIVIDEND_SHARE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendShare")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'EX_DIVIDEND_DATE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ExDividendDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'DIVIDEND_PAY_DATE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendPayDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'BOOK_VALUE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"BookValue")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PRICE_BOOK', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceBook")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PRICE_SALES', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceSales")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PRICE_EPS_EST_CURRENT_YEAR', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceEPSEstimateCurrentYear")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'PRICE_EPS_EST_NEXT_YEAR', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceEPSEstimateNextYear")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'EBITDA', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EBITDA")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'COMPANY_NAME', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Name")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'STOCK_EXCHANGE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"StockExchange")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'COMMISSION', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Commission")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'NOTES', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Notes")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'SYMBOL', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'LAST_TRADE_DATE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'LAST_TRADE_TIME', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'LAST', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PERCENT_CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'OPEN', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'HIGH', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'LOW', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'DAYS_RANGE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DaysRange")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PREV_CLOSE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PreviousClose")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'SHORT_RATIO', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ShortRatio")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'YEAR_HIGH', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearHigh")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'YEAR_LOW', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearLow")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'YEAR_RANGE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"YearRange")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'CHANGE_FROM_YEAR_HIGH', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromYearHigh")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'CHANGE_FROM_YEAR_LOW', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromYearLow")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PERCENT_CHANGE_FROM_YEAR_HIGH', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromYearHigh")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PERCENT_CHANGE_FROM_YEAR_LOW', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromYearLow")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'MA50', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"FiftydayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'MA200', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"TwoHundredDayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'CHANGE_FROM_MA50', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromFiftyDayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'CHANGE_FROM_MA200', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ChangeFromTwoHundredDayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PERCENT_CHANGE_FROM_MA50', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromFiftyDayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PERCENT_CHANGE_FROM_MA200', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PercentChangeFromTwoHundredDayMovingAverage")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'AVERAGE_DAILY_VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"AverageDailyVolume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'ONE_YEAR_TARGET_PRICE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"OneYrTargetPrice")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PERatio")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PEG', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PEGRatio")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'EPS_EST_CURRENT_YEAR', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateCurrentYear")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'EPS_EST_NEXT_QUARTER', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateNextQuarter")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'EPS_EST_NEXT_YEAR', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EPSEstimateNextYear")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'EARNINGS_SHARE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EarningsShare")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'MARKET_CAP', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"MarketCapitalization")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'DIVIDEND_YIELD', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendYield")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'DIVIDEND_SHARE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendShare")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'EX_DIVIDEND_DATE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"ExDividendDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'DIVIDEND_PAY_DATE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"DividendPayDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'BOOK_VALUE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"BookValue")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PRICE_BOOK', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceBook")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PRICE_SALES', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceSales")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PRICE_EPS_EST_CURRENT_YEAR', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceEPSEstimateCurrentYear")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'PRICE_EPS_EST_NEXT_YEAR', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"PriceEPSEstimateNextYear")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'EBITDA', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"EBITDA")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'COMPANY_NAME', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Name")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'STOCK_EXCHANGE', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"StockExchange")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'COMMISSION', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Commission")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'fundamentals_yahoo', N'NOTES', N'=RTD("gartle.rtd",,"YahooFinanceQuotes",[SYMBOL],"Notes")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'OPTION_CODE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionCode")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'SYMBOL', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'DATETIME', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'DATE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'TIME', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'OPTION_SYMBOL', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionSymbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'EXP_DATE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Exp")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'STRIKE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Strike")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'TYPE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Type")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'LAST', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'PERCENT_CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"ChangeInPercent")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'MARK', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Mark")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'BID', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'ASK', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_tick_history_yahoo', N'OPEN_INT', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OpenInt")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'OPTION_CODE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionCode")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'SYMBOL', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'DATETIME', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'DATE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'TIME', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'OPTION_SYMBOL', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionSymbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'EXP_DATE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Exp")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'STRIKE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Strike")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'TYPE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Type")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'LAST', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'PERCENT_CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"ChangeInPercent")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'MARK', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Mark")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'BID', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'ASK', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'option_day_history_yahoo', N'OPEN_INT', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OpenInt")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'OPTION_CODE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionCode")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'SYMBOL', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'DATETIME', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'DATE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'TIME', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"rtd_LastUpdateTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'OPTION_SYMBOL', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OptionSymbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'EXP_DATE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Exp")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'STRIKE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Strike")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'TYPE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Type")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'LAST', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'PERCENT_CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"ChangeInPercent")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'MARK', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Mark")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'BID', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'ASK', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'options_yahoo', N'OPEN_INT', N'=RTD("gartle.rtd",,"YahooFinanceOptions",[CODE],"OpenInt")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'SYMBOL', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'LAST_TRADE_DATETIME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDateTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'LAST_TRADE_DATE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'LAST_TRADE_TIME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'LAST', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'PERCENT_CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'OPEN', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'HIGH', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'LOW', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_yahoo', N'VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_yahoo', N'SYMBOL', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_yahoo', N'LAST_TRADE_DATE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_yahoo', N'LAST_TRADE_TIME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_yahoo', N'LAST', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_yahoo', N'CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_yahoo', N'PERCENT_CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_yahoo', N'OPEN', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_yahoo', N'HIGH', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_yahoo', N'LOW', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_yahoo', N'VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'SYMBOL', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'LAST_TRADE_DATETIME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDateTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'LAST_TRADE_DATE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'LAST_TRADE_TIME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'LAST', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'PERCENT_CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'OPEN', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'HIGH', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'LOW', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_yahoo', N'VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'SYMBOL', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'LAST_TRADE_DATETIME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDateTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'LAST_TRADE_DATE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeDate")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'LAST_TRADE_TIME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"LastTradeTime")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'LAST', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'PERCENT_CHANGE', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"ChangeInPercent")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'OPEN', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'HIGH', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'LOW', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_yahoo', N'VOLUME', N'=RTD("gartle.rtd",,"YahooFinanceWatchList",[SYMBOL],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'stocks_yahoo', N'SYMBOL', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'stocks_yahoo', N'COMPANY_NAME', N'=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"CompanyName")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'stocks_yahoo', N'SECTOR', N'=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"Sector")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'stocks_yahoo', N'INDUSTRY', N'=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"Industry")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'stocks_yahoo', N'FULLTIME_EMPLOYEES', N'=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"FullTimeEmployees")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'stocks_yahoo', N'TRADE_START', N'=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"Start")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'stocks_yahoo', N'TRADE_END', N'=RTD("gartle.rtd",,"YahooFinanceStocks",[SYMBOL],"End")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'SYMBOL', N'=VFX|Name![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'TIME', N'=VFX|Time![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'CHANGE', N'=VFX|NetChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'PERCENT_CHANGE', N'=VFX|PercentChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'BID', N'=VFX|Bid![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'ASK', N'=VFX|Ask![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'OPEN', N'=VFX|OpenPrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'HIGH', N'=VFX|High![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'LOW', N'=VFX|Low![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_vfx', N'CLOSE', N'=VFX|ClosePrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'SYMBOL', N'=VFX|Name![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'TIME', N'=VFX|Time![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'CHANGE', N'=VFX|NetChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'PERCENT_CHANGE', N'=VFX|PercentChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'BID', N'=VFX|Bid![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'ASK', N'=VFX|Ask![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'OPEN', N'=VFX|OpenPrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'HIGH', N'=VFX|High![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'LOW', N'=VFX|Low![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_vfx', N'CLOSE', N'=VFX|ClosePrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'SYMBOL', N'=VFX|Name![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'TIME', N'=VFX|Time![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'CHANGE', N'=VFX|NetChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'PERCENT_CHANGE', N'=VFX|PercentChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'BID', N'=VFX|Bid![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'ASK', N'=VFX|Ask![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'OPEN', N'=VFX|OpenPrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'HIGH', N'=VFX|High![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'LOW', N'=VFX|Low![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_vfx', N'CLOSE', N'=VFX|ClosePrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'SYMBOL', N'=VFX|Name![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'TIME', N'=VFX|Time![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'CHANGE', N'=VFX|NetChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'PERCENT_CHANGE', N'=VFX|PercentChange![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'BID', N'=VFX|Bid![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'ASK', N'=VFX|Ask![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'OPEN', N'=VFX|OpenPrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'HIGH', N'=VFX|High![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'LOW', N'=VFX|Low![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_vfx', N'CLOSE', N'=VFX|ClosePrice![CODE]', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'ID', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'SYMBOL', N'=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'TIME', N'=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'LAST', N'=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'TRADE_PRICE', N'=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'CHANGE', N'=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'PERCENT_CHANGE', N'=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'BID', N'=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'ASK', N'=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'BID_SIZE', N'=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'ASK_SIZE', N'=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'OPEN', N'=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'HIGH', N'=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'LOW', N'=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'VOLUME', N'=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_tick_history_es', N'OPEN_INT', N'=RTD("esrtd",,[CODE],"OpenInt")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'SYMBOL', N'=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'TIME', N'=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'LAST', N'=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'TRADE_PRICE', N'=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'CHANGE', N'=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'PERCENT_CHANGE', N'=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'BID', N'=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'ASK', N'=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'BID_SIZE', N'=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'ASK_SIZE', N'=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'OPEN', N'=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'HIGH', N'=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'LOW', N'=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'VOLUME', N'=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_time_history_es', N'OPEN_INT', N'=RTD("esrtd",,[CODE],"OpenInt")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'SYMBOL', N'=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'TIME', N'=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'LAST', N'=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'TRADE_PRICE', N'=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'CHANGE', N'=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'PERCENT_CHANGE', N'=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'BID', N'=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'ASK', N'=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'BID_SIZE', N'=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'ASK_SIZE', N'=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'OPEN', N'=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'HIGH', N'=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'LOW', N'=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'VOLUME', N'=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quote_day_history_es', N'OPEN_INT', N'=RTD("esrtd",,[CODE],"OpenInt")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'CODE', NULL, NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'SYMBOL', N'=RTD("esrtd",,[CODE],"Symbol")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'DATE', N'=Date()', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'TIME', N'=RTD("esrtd",,[CODE],"Time")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'LAST', N'=RTD("esrtd",,[CODE],"Last")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'TRADE_PRICE', N'=RTD("esrtd",,[CODE],"TradePrice")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'CHANGE', N'=RTD("esrtd",,[CODE],"Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'PERCENT_CHANGE', N'=RTD("esrtd",,[CODE],"% Change")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'BID', N'=RTD("esrtd",,[CODE],"Bid")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'ASK', N'=RTD("esrtd",,[CODE],"Ask")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'BID_SIZE', N'=RTD("esrtd",,[CODE],"Bid Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'ASK_SIZE', N'=RTD("esrtd",,[CODE],"Ask Size")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'OPEN', N'=RTD("esrtd",,[CODE],"Open")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'HIGH', N'=RTD("esrtd",,[CODE],"High")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'LOW', N'=RTD("esrtd",,[CODE],"Low")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'VOLUME', N'=RTD("esrtd",,[CODE],"Volume")', NULL);
INSERT INTO `rtd`.`real_time_formulas` (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, RTD_FORMULA, IS_DISABLED) VALUES (N'rtd', N'quotes_es', N'OPEN_INT', N'=RTD("esrtd",,[CODE],"OpenInt")', NULL);

INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'fundamentals_day_history_yahoo', N'SELECT CODE AS SYMBOL FROM rtd.quote_list_stocks', NULL, NULL, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'fundamentals_yahoo', N'SELECT CODE AS SYMBOL FROM rtd.quote_list_stocks', NULL, NULL, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'option_day_history_tos', N'SELECT CODE FROM rtd.option_list_tos', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'option_day_history_tws', N'SELECT TICK_ID, CODE FROM rtd.quote_list_tws WHERE CODE LIKE ''%_OPT_20%''', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'option_day_history_yahoo', N'SELECT CODE FROM rtd.option_list_yahoo', NULL, NULL, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'options_tos', N'SELECT CODE FROM rtd.option_list_tos', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'options_tws', N'SELECT TICK_ID, CODE FROM rtd.quote_list_tws WHERE CODE LIKE ''%_OPT_20%''', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'options_yahoo', N'SELECT CODE FROM rtd.option_list_yahoo', NULL, NULL, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'option_tick_history_tos', N'SELECT CODE FROM rtd.option_list_tos', 1, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'option_tick_history_tws', N'SELECT TICK_ID, CODE FROM rtd.quote_list_tws WHERE CODE LIKE ''%_OPT_20%''', 1, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'option_tick_history_yahoo', N'SELECT CODE FROM rtd.option_list_yahoo', 1, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_day_history_es', N'SELECT CODE FROM rtd.quote_list_es', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_day_history_tos', N'SELECT CODE AS SYMBOL FROM rtd.quote_list_tos', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_day_history_tws', N'SELECT TICK_ID, CODE AS SYMBOL FROM rtd.quote_list_tws WHERE CODE NOT LIKE ''%_OPT_20%''', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_day_history_vfx', N'SELECT CODE FROM rtd.quote_list_vfx', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_day_history_yahoo', N'SELECT CODE AS SYMBOL FROM rtd.quote_list_yahoo', NULL, NULL, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quotes_es', N'SELECT CODE FROM rtd.quote_list_es', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quotes_tos', N'SELECT CODE AS SYMBOL FROM rtd.quote_list_tos', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quotes_tws', N'SELECT TICK_ID, CODE AS SYMBOL FROM rtd.quote_list_tws WHERE CODE NOT LIKE ''%_OPT_20%''', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quotes_vfx', N'SELECT CODE FROM rtd.quote_list_vfx', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quotes_yahoo', N'SELECT CODE AS SYMBOL FROM rtd.quote_list_yahoo', NULL, NULL, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_tick_history_es', N'SELECT CODE FROM rtd.quote_list_es', 1, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_tick_history_tos', N'SELECT CODE AS SYMBOL FROM rtd.quote_list_tos', 1, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_tick_history_tws', N'SELECT TICK_ID, CODE AS SYMBOL FROM rtd.quote_list_tws WHERE CODE NOT LIKE ''%_OPT_20%''', 1, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_tick_history_vfx', N'SELECT CODE FROM rtd.quote_list_vfx', 1, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_tick_history_yahoo', N'SELECT CODE AS SYMBOL FROM rtd.quote_list_yahoo', 1, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_time_history_es', N'SELECT CODE FROM rtd.quote_list_es', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_time_history_vfx', N'SELECT CODE FROM rtd.quote_list_vfx', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'quote_time_history_yahoo', N'SELECT CODE AS SYMBOL FROM rtd.quote_list_yahoo', NULL, 1, N'Eastern Standard Time', NULL);
INSERT INTO `rtd`.`real_time_tables` (TABLE_SCHEMA, TABLE_NAME, LOAD_CODE, IS_HISTORY, IS_DISABLED, TIME_ZONE, RTD_INSTANCE_NAME) VALUES (N'rtd', N'stocks_yahoo', N'SELECT CODE AS SYMBOL FROM rtd.quote_list_stocks', NULL, NULL, N'Eastern Standard Time', NULL);

INSERT INTO `rtd`.`option_list_tos` (`CODE`) VALUES (N'.AAPL150117C500');
INSERT INTO `rtd`.`option_list_tos` (`CODE`) VALUES (N'.AAPL150117C600');
INSERT INTO `rtd`.`option_list_tos` (`CODE`) VALUES (N'.AAPL150117P500');
INSERT INTO `rtd`.`option_list_tos` (`CODE`) VALUES (N'.AAPL150117P600');
INSERT INTO `rtd`.`option_list_yahoo` (`CODE`) VALUES (N'AAPL150117C00500000');
INSERT INTO `rtd`.`option_list_yahoo` (`CODE`) VALUES (N'AAPL150117C00600000');
INSERT INTO `rtd`.`option_list_yahoo` (`CODE`) VALUES (N'AAPL150117P00500000');
INSERT INTO `rtd`.`option_list_yahoo` (`CODE`) VALUES (N'AAPL150117P00600000');
INSERT INTO `rtd`.`quote_list_es` (`CODE`) VALUES (N'AAPL');
INSERT INTO `rtd`.`quote_list_es` (`CODE`) VALUES (N'GOOG');
INSERT INTO `rtd`.`quote_list_es` (`CODE`) VALUES (N'MSFT');
INSERT INTO `rtd`.`quote_list_es` (`CODE`) VALUES (N'ORCL');
INSERT INTO `rtd`.`quote_list_es` (`CODE`) VALUES (N'FB');
INSERT INTO `rtd`.`quote_list_es` (`CODE`) VALUES (N'LNKD');
INSERT INTO `rtd`.`quote_list_es` (`CODE`) VALUES (N'YHOO');
INSERT INTO `rtd`.`quote_list_stocks` (`CODE`) VALUES (N'AAPL');
INSERT INTO `rtd`.`quote_list_stocks` (`CODE`) VALUES (N'GOOG');
INSERT INTO `rtd`.`quote_list_stocks` (`CODE`) VALUES (N'MSFT');
INSERT INTO `rtd`.`quote_list_stocks` (`CODE`) VALUES (N'ORCL');
INSERT INTO `rtd`.`quote_list_stocks` (`CODE`) VALUES (N'FB');
INSERT INTO `rtd`.`quote_list_stocks` (`CODE`) VALUES (N'LNKD');
INSERT INTO `rtd`.`quote_list_stocks` (`CODE`) VALUES (N'YHOO');
INSERT INTO `rtd`.`quote_list_tos` (`CODE`) VALUES (N'/ES');
INSERT INTO `rtd`.`quote_list_tos` (`CODE`) VALUES (N'AAPL');
INSERT INTO `rtd`.`quote_list_tos` (`CODE`) VALUES (N'GOOG');
INSERT INTO `rtd`.`quote_list_tos` (`CODE`) VALUES (N'MSFT');
INSERT INTO `rtd`.`quote_list_tos` (`CODE`) VALUES (N'ORCL');
INSERT INTO `rtd`.`quote_list_tos` (`CODE`) VALUES (N'FB');
INSERT INTO `rtd`.`quote_list_tos` (`CODE`) VALUES (N'LNKD');
INSERT INTO `rtd`.`quote_list_tos` (`CODE`) VALUES (N'YHOO');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'AAPL');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'GOOG');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'MSFT');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'ORCL');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'FB');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'LNKD');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'YHOO');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'AAPL_OPT_20150116_500_C_100_SMART_USD_~');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'AAPL_OPT_20150116_600_C_100_SMART_USD_~');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'AAPL_OPT_20150116_500_P_100_SMART_USD_~');
INSERT INTO `rtd`.`quote_list_tws` (`CODE`) VALUES (N'AAPL_OPT_20150116_600_P_100_SMART_USD_~');
INSERT INTO `rtd`.`quote_list_vfx` (`CODE`) VALUES (N'EUR_USD');
INSERT INTO `rtd`.`quote_list_vfx` (`CODE`) VALUES (N'GBP_USD');
INSERT INTO `rtd`.`quote_list_vfx` (`CODE`) VALUES (N'USD_CHF');
INSERT INTO `rtd`.`quote_list_vfx` (`CODE`) VALUES (N'USD_JPY');
INSERT INTO `rtd`.`quote_list_yahoo` (`CODE`) VALUES (N'AAPL');
INSERT INTO `rtd`.`quote_list_yahoo` (`CODE`) VALUES (N'GOOG');
INSERT INTO `rtd`.`quote_list_yahoo` (`CODE`) VALUES (N'MSFT');
INSERT INTO `rtd`.`quote_list_yahoo` (`CODE`) VALUES (N'ORCL');
INSERT INTO `rtd`.`quote_list_yahoo` (`CODE`) VALUES (N'FB');
INSERT INTO `rtd`.`quote_list_yahoo` (`CODE`) VALUES (N'LNKD');
INSERT INTO `rtd`.`quote_list_yahoo` (`CODE`) VALUES (N'YHOO');

CREATE OR REPLACE VIEW `rtdxls`.`fundamentals_day_history_yahoo`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , MAX(t.`LAST_TRADE_DATE`) AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"LastTradeTime")' AS `LastTradeTime`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"DaysRange")' AS `DaysRange`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PrevClose")' AS `PrevClose`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"ShortRatio")' AS `ShortRatio`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"YearHigh")' AS `YearHigh`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"YearLow")' AS `YearLow`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"YearRange")' AS `YearRange`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"ChangeFromYearHigh")' AS `ChangeFromYearHigh`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"ChangeFromYearLow")' AS `ChangeFromYearLow`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PercentChangeFromYearHigh")' AS `PercentChangeFromYearHigh`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PercentChangeFromYearLow")' AS `PercentChangeFromYearLow`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"MA50")' AS `MA50`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"MA200")' AS `MA200`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"ChangeFromMA50")' AS `ChangeFromMA50`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"ChangeFromMA200")' AS `ChangeFromMA200`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PercentChangeFromMA50")' AS `PercentChangeFromMA50`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PercentChangeFromMA200")' AS `PercentChangeFromMA200`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"AverageDailyVolume")' AS `AverageDailyVolume`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"OneYearTargetPrice")' AS `OneYearTargetPrice`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PE")' AS `PE`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PEG")' AS `PEG`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"EPSEstCurrentYear")' AS `EPSEstCurrentYear`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"EPSEstNextQuarter")' AS `EPSEstNextQuarter`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"EPSEstNextYear")' AS `EPSEstNextYear`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"EarningsShare")' AS `EarningsShare`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"MarketCap")' AS `MarketCap`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"DividendYield")' AS `DividendYield`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"DividendShare")' AS `DividendShare`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"ExDividendDate")' AS `ExDividendDate`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"DividendPayDate")' AS `DividendPayDate`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"BookValue")' AS `BookValue`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PriceBook")' AS `PriceBook`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PriceSales")' AS `PriceSales`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PriceEPSEstCurrentYear")' AS `PriceEPSEstCurrentYear`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"PriceEPSEstNextYear")' AS `PriceEPSEstNextYear`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"EBITDA")' AS `EBITDA`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"CompanyName")' AS `CompanyName`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"StockExchange")' AS `StockExchange`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"Commission")' AS `Commission`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"Notes")' AS `Notes`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_day_history_yahoo",[Symbol],[Date],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`fundamentals_day_history_yahoo` t
GROUP BY
    t.`SYMBOL`;

CREATE OR REPLACE VIEW `rtdxls`.`fundamentals_yahoo`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"LastTradeDate")' AS `LastTradeDate`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"LastTradeTime")' AS `LastTradeTime`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"DaysRange")' AS `DaysRange`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PrevClose")' AS `PrevClose`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"ShortRatio")' AS `ShortRatio`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"YearHigh")' AS `YearHigh`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"YearLow")' AS `YearLow`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"YearRange")' AS `YearRange`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"ChangeFromYearHigh")' AS `ChangeFromYearHigh`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"ChangeFromYearLow")' AS `ChangeFromYearLow`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PercentChangeFromYearHigh")' AS `PercentChangeFromYearHigh`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PercentChangeFromYearLow")' AS `PercentChangeFromYearLow`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"MA50")' AS `MA50`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"MA200")' AS `MA200`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"ChangeFromMA50")' AS `ChangeFromMA50`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"ChangeFromMA200")' AS `ChangeFromMA200`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PercentChangeFromMA50")' AS `PercentChangeFromMA50`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PercentChangeFromMA200")' AS `PercentChangeFromMA200`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"AverageDailyVolume")' AS `AverageDailyVolume`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"OneYearTargetPrice")' AS `OneYearTargetPrice`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PE")' AS `PE`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PEG")' AS `PEG`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"EPSEstCurrentYear")' AS `EPSEstCurrentYear`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"EPSEstNextQuarter")' AS `EPSEstNextQuarter`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"EPSEstNextYear")' AS `EPSEstNextYear`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"EarningsShare")' AS `EarningsShare`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"MarketCap")' AS `MarketCap`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"DividendYield")' AS `DividendYield`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"DividendShare")' AS `DividendShare`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"ExDividendDate")' AS `ExDividendDate`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"DividendPayDate")' AS `DividendPayDate`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"BookValue")' AS `BookValue`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PriceBook")' AS `PriceBook`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PriceSales")' AS `PriceSales`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PriceEPSEstCurrentYear")' AS `PriceEPSEstCurrentYear`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"PriceEPSEstNextYear")' AS `PriceEPSEstNextYear`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"EBITDA")' AS `EBITDA`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"CompanyName")' AS `CompanyName`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"StockExchange")' AS `StockExchange`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"Commission")' AS `Commission`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"Notes")' AS `Notes`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","fundamentals_yahoo",[Symbol],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`fundamentals_yahoo` t;

CREATE OR REPLACE VIEW `rtdxls`.`option_day_history_tos`
AS

SELECT
    t.`CODE` AS `Code`
    , MAX(t.`DATE`) AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Description")' AS `Description`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"LastSize")' AS `LastSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"LastX")' AS `LastX`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Mark")' AS `Mark`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"MarkChange")' AS `MarkChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"MarkPercentChange")' AS `MarkPercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"BidSize")' AS `BidSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"AskSize")' AS `AskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"BidAskSize")' AS `BidAskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"BidX")' AS `BidX`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"AskX")' AS `AskX`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Close")' AS `Close`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"OpenInt")' AS `OpenInt`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"ImpliedVol")' AS `ImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Delta")' AS `Delta`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Gamma")' AS `Gamma`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Theta")' AS `Theta`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Vega")' AS `Vega`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Rho")' AS `Rho`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Extrinsic")' AS `Extrinsic`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"Intrinsic")' AS `Intrinsic`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"ProbabilityITM")' AS `ProbabilityITM`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"ProbabilityOTM")' AS `ProbabilityOTM`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"ProbabilityTouch")' AS `ProbabilityTouch`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"CoveredReturn")' AS `CoveredReturn`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"MaxCoveredReturn")' AS `MaxCoveredReturn`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tos",[Code],[Date],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`option_day_history_tos` t
GROUP BY
    t.`CODE`;

CREATE OR REPLACE VIEW `rtdxls`.`option_day_history_tws`
AS

SELECT
    t.`CODE` AS `Code`
    , MAX(t.`DATE`) AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"LastSize")' AS `LastSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"BidSize")' AS `BidSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"AskSize")' AS `AskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Close")' AS `Close`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"UnderlyingPrice")' AS `UnderlyingPrice`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"ModelPrice")' AS `ModelPrice`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"ImpliedVol")' AS `ImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"BidImpliedVol")' AS `BidImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"AskImpliedVol")' AS `AskImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"LastImpliedVol")' AS `LastImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"BidDelta")' AS `BidDelta`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"AskDelta")' AS `AskDelta`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"LastDelta")' AS `LastDelta`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Delta")' AS `Delta`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Gamma")' AS `Gamma`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Theta")' AS `Theta`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"Vega")' AS `Vega`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"pvDividend")' AS `pvDividend`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_tws",[Code],[Date],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`option_day_history_tws` t
GROUP BY
    t.`CODE`;

CREATE OR REPLACE VIEW `rtdxls`.`option_day_history_yahoo`
AS

SELECT
    t.`CODE` AS `Code`
    , MAX(t.`DATE`) AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"OptionCode")' AS `OptionCode`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"Symbol")' AS `Symbol`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"OptionSymbol")' AS `OptionSymbol`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"ExpDate")' AS `ExpDate`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"Strike")' AS `Strike`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"Type")' AS `Type`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"Mark")' AS `Mark`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"OpenInt")' AS `OpenInt`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","option_day_history_yahoo",[Code],[Date],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`option_day_history_yahoo` t
GROUP BY
    t.`CODE`;

CREATE OR REPLACE VIEW `rtdxls`.`options_tos`
AS

SELECT
    t.`CODE` AS `Code`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Date")' AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Description")' AS `Description`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"LastSize")' AS `LastSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"LastX")' AS `LastX`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Mark")' AS `Mark`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"MarkChange")' AS `MarkChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"MarkPercentChange")' AS `MarkPercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"BidSize")' AS `BidSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"AskSize")' AS `AskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"BidAskSize")' AS `BidAskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"BidX")' AS `BidX`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"AskX")' AS `AskX`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Close")' AS `Close`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"OpenInt")' AS `OpenInt`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"ImpliedVol")' AS `ImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Delta")' AS `Delta`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Gamma")' AS `Gamma`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Theta")' AS `Theta`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Vega")' AS `Vega`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Rho")' AS `Rho`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Extrinsic")' AS `Extrinsic`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"Intrinsic")' AS `Intrinsic`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"ProbabilityITM")' AS `ProbabilityITM`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"ProbabilityOTM")' AS `ProbabilityOTM`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"ProbabilityTouch")' AS `ProbabilityTouch`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"CoveredReturn")' AS `CoveredReturn`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"MaxCoveredReturn")' AS `MaxCoveredReturn`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tos",[Code],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`options_tos` t;

CREATE OR REPLACE VIEW `rtdxls`.`options_tws`
AS

SELECT
    t.`CODE` AS `Code`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Date")' AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"LastSize")' AS `LastSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"BidSize")' AS `BidSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"AskSize")' AS `AskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Close")' AS `Close`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"UnderlyingPrice")' AS `UnderlyingPrice`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"ModelPrice")' AS `ModelPrice`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"ImpliedVol")' AS `ImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"BidImpliedVol")' AS `BidImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"AskImpliedVol")' AS `AskImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"LastImpliedVol")' AS `LastImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"BidDelta")' AS `BidDelta`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"AskDelta")' AS `AskDelta`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"LastDelta")' AS `LastDelta`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Delta")' AS `Delta`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Gamma")' AS `Gamma`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Theta")' AS `Theta`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"Vega")' AS `Vega`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"pvDividend")' AS `pvDividend`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_tws",[Code],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`options_tws` t;

CREATE OR REPLACE VIEW `rtdxls`.`options_yahoo`
AS

SELECT
    t.`CODE` AS `Code`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Date")' AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"OptionCode")' AS `OptionCode`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Symbol")' AS `Symbol`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"OptionSymbol")' AS `OptionSymbol`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"ExpDate")' AS `ExpDate`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Strike")' AS `Strike`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Type")' AS `Type`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Mark")' AS `Mark`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"OpenInt")' AS `OpenInt`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","options_yahoo",[Code],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`options_yahoo` t;

CREATE OR REPLACE VIEW `rtdxls`.`quote_day_history_es`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , MAX(t.`DATE`) AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"BidSize")' AS `BidSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"AskSize")' AS `AskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"OpenInt")' AS `OpenInt`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"TradePrice")' AS `TradePrice`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_es",[Symbol],[Date],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`quote_day_history_es` t
GROUP BY
    t.`SYMBOL`;

CREATE OR REPLACE VIEW `rtdxls`.`quote_day_history_tos`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , MAX(t.`DATE`) AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Description")' AS `Description`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"LastSize")' AS `LastSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"LastX")' AS `LastX`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Mark")' AS `Mark`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"MarkChange")' AS `MarkChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"MarkPercentChange")' AS `MarkPercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"BidSize")' AS `BidSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"AskSize")' AS `AskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"BidAskSize")' AS `BidAskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"BidX")' AS `BidX`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"AskX")' AS `AskX`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"StrengthMeter")' AS `StrengthMeter`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Close")' AS `Close`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"OpenInt")' AS `OpenInt`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"ImpliedVol")' AS `ImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"VolIndex")' AS `VolIndex`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"FrontVol")' AS `FrontVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"BackVol")' AS `BackVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"WeightedBackVol")' AS `WeightedBackVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"VolDiff")' AS `VolDiff`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"PutCallRatio")' AS `PutCallRatio`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"CallVolumeIndex")' AS `CallVolumeIndex`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"PutVolumeIndex")' AS `PutVolumeIndex`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"OptionVolumeIndex")' AS `OptionVolumeIndex`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"FrontExpectedMove")' AS `FrontExpectedMove`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"BackExpectedMove")' AS `BackExpectedMove`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"ExpectedMoveDiff")' AS `ExpectedMoveDiff`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Beta")' AS `Beta`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"High52")' AS `High52`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Low52")' AS `Low52`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"PE")' AS `PE`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"EPS")' AS `EPS`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"MarketCap")' AS `MarketCap`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"Shares")' AS `Shares`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"DividendYield")' AS `DividendYield`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"DividendShare")' AS `DividendShare`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tos",[Symbol],[Date],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`quote_day_history_tos` t
GROUP BY
    t.`SYMBOL`;

CREATE OR REPLACE VIEW `rtdxls`.`quote_day_history_tws`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , MAX(t.`DATE`) AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"LastSize")' AS `LastSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"BidSize")' AS `BidSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"AskSize")' AS `AskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"Close")' AS `Close`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_tws",[Symbol],[Date],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`quote_day_history_tws` t
GROUP BY
    t.`SYMBOL`;

CREATE OR REPLACE VIEW `rtdxls`.`quote_day_history_vfx`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , MAX(t.`DATE`) AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"Close")' AS `Close`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_vfx",[Symbol],[Date],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`quote_day_history_vfx` t
GROUP BY
    t.`SYMBOL`;

CREATE OR REPLACE VIEW `rtdxls`.`quote_day_history_yahoo`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , MAX(t.`LAST_TRADE_DATE`) AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_yahoo",[Symbol],[Date],"LastTradeTime")' AS `LastTradeTime`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_yahoo",[Symbol],[Date],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_yahoo",[Symbol],[Date],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_yahoo",[Symbol],[Date],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_yahoo",[Symbol],[Date],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_yahoo",[Symbol],[Date],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_yahoo",[Symbol],[Date],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_yahoo",[Symbol],[Date],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_yahoo",[Symbol],[Date],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","quote_day_history_yahoo",[Symbol],[Date],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`quote_day_history_yahoo` t
GROUP BY
    t.`SYMBOL`;

CREATE OR REPLACE VIEW `rtdxls`.`quotes_es`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"Date")' AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"BidSize")' AS `BidSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"AskSize")' AS `AskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"OpenInt")' AS `OpenInt`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"TradePrice")' AS `TradePrice`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_es",[Symbol],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`quotes_es` t;

CREATE OR REPLACE VIEW `rtdxls`.`quotes_tos`
AS

SELECT
    t.`SYMBOL`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Date")' AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Description")' AS `Description`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"LastSize")' AS `LastSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"LastX")' AS `LastX`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Mark")' AS `Mark`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"MarkChange")' AS `MarkChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"MarkPercentChange")' AS `MarkPercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"BidSize")' AS `BidSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"AskSize")' AS `AskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"BidAskSize")' AS `BidAskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"BidX")' AS `BidX`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"AskX")' AS `AskX`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"StrengthMeter")' AS `StrengthMeter`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Close")' AS `Close`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"OpenInt")' AS `OpenInt`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"ImpliedVol")' AS `ImpliedVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"VolIndex")' AS `VolIndex`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"FrontVol")' AS `FrontVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"BackVol")' AS `BackVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"WeightedBackVol")' AS `WeightedBackVol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"VolDiff")' AS `VolDiff`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"PutCallRatio")' AS `PutCallRatio`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"CallVolumeIndex")' AS `CallVolumeIndex`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"PutVolumeIndex")' AS `PutVolumeIndex`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"OptionVolumeIndex")' AS `OptionVolumeIndex`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"FrontExpectedMove")' AS `FrontExpectedMove`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"BackExpectedMove")' AS `BackExpectedMove`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"ExpectedMoveDiff")' AS `ExpectedMoveDiff`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Beta")' AS `Beta`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"High52")' AS `High52`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Low52")' AS `Low52`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"PE")' AS `PE`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"EPS")' AS `EPS`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"MarketCap")' AS `MarketCap`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"Shares")' AS `Shares`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"DividendYield")' AS `DividendYield`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"DividendShare")' AS `DividendShare`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tos",[Symbol],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`quotes_tos` t;

CREATE OR REPLACE VIEW `rtdxls`.`quotes_tws`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"Date")' AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"LastSize")' AS `LastSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"BidSize")' AS `BidSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"AskSize")' AS `AskSize`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"Close")' AS `Close`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_tws",[Symbol],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`quotes_tws` t;

CREATE OR REPLACE VIEW `rtdxls`.`quotes_vfx`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"Date")' AS `Date`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"Time")' AS `Time`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"Bid")' AS `Bid`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"Ask")' AS `Ask`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"Close")' AS `Close`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_vfx",[Symbol],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`quotes_vfx` t;

CREATE OR REPLACE VIEW `rtdxls`.`quotes_yahoo`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"LastTradeDate")' AS `LastTradeDate`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"LastTradeTime")' AS `LastTradeTime`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"Last")' AS `Last`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"Change")' AS `Change`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"PercentChange")' AS `PercentChange`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"Open")' AS `Open`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"High")' AS `High`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"Low")' AS `Low`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"Volume")' AS `Volume`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
    , '=RTD("gartle.rtd",,"rtd-mysql","quotes_yahoo",[Symbol],"RTD_LastMessage")' AS `RTD_LastMessage`
FROM
    `rtd`.`quotes_yahoo` t;

CREATE OR REPLACE VIEW `rtdxls`.`stocks_yahoo`
AS

SELECT
    t.`SYMBOL` AS `Symbol`
    , '=RTD("gartle.rtd",,"rtd-mysql","stocks_yahoo",[Symbol],"CompanyName")' AS `CompanyName`
    , '=RTD("gartle.rtd",,"rtd-mysql","stocks_yahoo",[Symbol],"Sector")' AS `Sector`
    , '=RTD("gartle.rtd",,"rtd-mysql","stocks_yahoo",[Symbol],"Industry")' AS `Industry`
    , '=RTD("gartle.rtd",,"rtd-mysql","stocks_yahoo",[Symbol],"FullTimeEmployees")' AS `FullTimeEmployees`
    , '=RTD("gartle.rtd",,"rtd-mysql","stocks_yahoo",[Symbol],"TradeStart")' AS `TradeStart`
    , '=RTD("gartle.rtd",,"rtd-mysql","stocks_yahoo",[Symbol],"TradeEnd")' AS `TradeEnd`
    , '=RTD("gartle.rtd",,"rtd-mysql","stocks_yahoo",[Symbol],"LastUpdateTimeStamp")' AS `LastUpdateTimeStamp`
FROM
    `rtd`.`stocks_yahoo` t;

CREATE OR REPLACE VIEW `rtdxls`.`real_time_views`
AS

SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , NULL AS INSERT_PROCEDURE
    , NULL AS UPDATE_PROCEDURE
    , NULL AS DELETE_PROCEDURE
FROM
    INFORMATION_SCHEMA.TABLES t
WHERE
    t.TABLE_SCHEMA = 'rtdxls'
    AND t.TABLE_TYPE = 'VIEW'
    AND t.TABLE_NAME NOT IN ('real_time_views');

-- print RTD objects have been created
